{% load i18n %}
<div id="tag_preview_{{ tag.id }}" class="module">
    <table>
        <caption>{% blocktrans with tag.name as tag_name %}Objects with tag "{{ tag_name }}"{% endblocktrans %}</caption>
        <tbody>
        {% block previews %}
        {% for object in objects %}
            <tr><td>{% block object %}{{ object }}{% endblock %}</td></tr>
        {% endfor %}
        {% endblock %}

        {% block more %}
            {% if more %}
                <tr><td><a href="{% url tag-preview ctype.id tag.id %}?skip={{ skip }}&top={{ top }}" class="more">{% blocktrans with more as count %}{{ count }} more{% endblocktrans %}</a>.</td></tr>
            {% endif %}
        {% endblock %}
        </tbody>
    </table>
</div>
