ul.tag-cloud {line-height: 4em; padding-left: 0;}
li.tag {display: inline; list-style: none;}

form.tag-cloud {text-align: right;}
input[disabled] {display: none;}

.c1 {font-size: 1em;}
.c1 sup {font-size: 0.8em;}
.c2 {font-size: 2em;}
.c2 sup {font-size: 0.4em;}
.c3 {font-size: 3em;}
.c3 sup {font-size: 0.27em;}
.c4 {font-size: 4em;}
.c4 sup {font-size: 0.2em;}

.tag {cursor: move; white-space: nowrap;}
.tag.active {color: red;}
.tag.hover {color: blue;}
.tag form {display: inline;}
.tag input {font-size: 1em;}

#content-main {width: 800px; margin-right: 2em;}
#content-related {position: static; float: left;}

.tooltip {
    position: absolute; top: 0; left: 0; z-index: 3; display: none;
    width: 400px;
    font-size: 16px;
    line-height: 1em;
    padding: 0px;
}
.tooltip table {width: 100%;}
